==> ciscoisesdk-0.1.0.tar.gz: ciscoisesdk-0.1.0/ciscoisesdk/models/validators/v3_0_0/jsd_f7227b280b745b94bb801369b168a529.py <==
# -*- coding: utf-8 -*-
"""Identity Services Engine updateInternaluserById data model.

Copyright (c) 2021 Cisco and/or its affiliates.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from ciscoisesdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidatorF7227B280B745B94Bb801369B168A529(object):
    """updateInternaluserById request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorF7227B280B745B94Bb801369B168A529, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "InternalUser": {
                "properties": {
                "changePassword": {
                "type": "boolean"
                },
                "customAttributes": {
                "properties": {
                "key1": {
                "type": "string"
                },
                "key2": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "description":
                 {
                "type": "string"
                },
                "email": {
                "type": "string"
                },
                "enablePassword": {
                "type": "string"
                },
                "enabled": {
                "type": "boolean"
                },
                "expiryDate": {
                "type": "string"
                },
                "expiryDateEnabled": {
                "type": "boolean"
                },
                "firstName": {
                "type": "string"
                },
                "id": {
                "type": "string"
                },
                "identityGroups": {
                "type": "string"
                },
                "lastName": {
                "type": "string"
                },
                "name": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "passwordIDStore": {
                "type": "string"
                }
                },
                "required": [
                "name",
                "enabled",
                "password"
                ],
                "type": "object"
                }
                },
                "required": [
                "InternalUser"
                ],
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> ciscoisesdk-2.2.0.tar.gz: ciscoisesdk-2.2.0/ciscoisesdk/models/validators/v3_1_0/jsd_f7227b280b745b94bb801369b168a529.py <==
# -*- coding: utf-8 -*-
"""Identity Services Engine updateInternalUserById data model.

Copyright (c) 2021 Cisco and/or its affiliates.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema
from ciscoisesdk.exceptions import MalformedRequest


class JSONSchemaValidatorF7227B280B745B94Bb801369B168A529(object):
    """updateInternalUserById request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorF7227B280B745B94Bb801369B168A529, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "InternalUser": {
                "properties": {
                "changePassword": {
                "type": "boolean"
                },
                "customAttributes": {
                "type": "object"
                },
                "description":
                 {
                "type": "string"
                },
                "email": {
                "type": "string"
                },
                "enablePassword": {
                "type": "string"
                },
                "enabled": {
                "type": "boolean"
                },
                "expiryDate": {
                "type": "string"
                },
                "expiryDateEnabled": {
                "type": "boolean"
                },
                "firstName": {
                "type": "string"
                },
                "id": {
                "type": "string"
                },
                "identityGroups": {
                "type": "string"
                },
                "lastName": {
                "type": "string"
                },
                "name": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "passwordIDStore": {
                "type": "string"
                }
                },
                "type": "object"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )
